summaryrefslogtreecommitdiff
path: root/src/html/html_olist_element.h
diff options
context:
space:
mode:
authorVincent Sanders <vince@kyllikki.org>2015-10-23 11:55:51 +0100
committerVincent Sanders <vince@kyllikki.org>2015-10-23 15:31:40 +0100
commit89fe0e619357ddf707a2d301794b9ceb928a7836 (patch)
tree35e37d9a2454318d9baea522a1b52eb2eccc5e3a /src/html/html_olist_element.h
parent0338d09eea66ede52ee364b8ca05986054bd077c (diff)
downloadlibdom-89fe0e619357ddf707a2d301794b9ceb928a7836.tar.gz
libdom-89fe0e619357ddf707a2d301794b9ceb928a7836.tar.bz2
Make HTMLOList IDL to c name mapping consistant
Diffstat (limited to 'src/html/html_olist_element.h')
-rw-r--r--src/html/html_olist_element.h42
1 files changed, 21 insertions, 21 deletions
diff --git a/src/html/html_olist_element.h b/src/html/html_olist_element.h
index 301d8ac..70601e8 100644
--- a/src/html/html_olist_element.h
+++ b/src/html/html_olist_element.h
@@ -6,47 +6,47 @@
* Copyright 2014 Rupinder Singh Khokhar <rsk1coder99@gmail.com>
*/
-#ifndef dom_internal_html_o_list_element_h_
-#define dom_internal_html_o_list_element_h_
+#ifndef dom_internal_html_olist_element_h_
+#define dom_internal_html_olist_element_h_
#include <dom/html/html_olist_element.h>
#include "html/html_element.h"
-struct dom_html_o_list_element {
+struct dom_html_olist_element {
struct dom_html_element base;
/**< The base class */
};
-/* Create a dom_html_o_list_element object */
-dom_exception _dom_html_o_list_element_create(struct dom_html_document *doc,
+/* Create a dom_html_olist_element object */
+dom_exception _dom_html_olist_element_create(struct dom_html_document *doc,
dom_string *namespace, dom_string *o_listfix,
- struct dom_html_o_list_element **ele);
+ struct dom_html_olist_element **ele);
-/* Initialise a dom_html_o_list_element object */
-dom_exception _dom_html_o_list_element_initialise(struct dom_html_document *doc,
+/* Initialise a dom_html_olist_element object */
+dom_exception _dom_html_olist_element_initialise(struct dom_html_document *doc,
dom_string *namespace, dom_string *o_listfix,
- struct dom_html_o_list_element *ele);
+ struct dom_html_olist_element *ele);
-/* Finalise a dom_html_o_list_element object */
-void _dom_html_o_list_element_finalise(struct dom_html_o_list_element *ele);
+/* Finalise a dom_html_olist_element object */
+void _dom_html_olist_element_finalise(struct dom_html_olist_element *ele);
-/* Destroy a dom_html_o_list_element object */
-void _dom_html_o_list_element_destroy(struct dom_html_o_list_element *ele);
+/* Destroy a dom_html_olist_element object */
+void _dom_html_olist_element_destroy(struct dom_html_olist_element *ele);
/* The protected virtual functions */
-dom_exception _dom_html_o_list_element_parse_attribute(dom_element *ele,
+dom_exception _dom_html_olist_element_parse_attribute(dom_element *ele,
dom_string *name, dom_string *value,
dom_string **parsed);
-void _dom_virtual_html_o_list_element_destroy(dom_node_internal *node);
-dom_exception _dom_html_o_list_element_copy(dom_node_internal *old,
+void _dom_virtual_html_olist_element_destroy(dom_node_internal *node);
+dom_exception _dom_html_olist_element_copy(dom_node_internal *old,
dom_node_internal **copy);
-#define DOM_HTML_O_LIST_ELEMENT_PROTECT_VTABLE \
- _dom_html_o_list_element_parse_attribute
+#define DOM_HTML_OLIST_ELEMENT_PROTECT_VTABLE \
+ _dom_html_olist_element_parse_attribute
-#define DOM_NODE_PROTECT_VTABLE_HTML_O_LIST_ELEMENT \
- _dom_virtual_html_o_list_element_destroy, \
- _dom_html_o_list_element_copy
+#define DOM_NODE_PROTECT_VTABLE_HTML_OLIST_ELEMENT \
+ _dom_virtual_html_olist_element_destroy, \
+ _dom_html_olist_element_copy
#endif